==> wire-runtime-3.1.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-enum-type/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [EnumType](./index.md)

# EnumType

`class EnumType : `[`Type`](../-type/index.md)

### Properties

| Name | Summary |
|---|---|
| [constants](constants.md) | `val constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstant`](../-enum-constant/index.md)`>` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [nestedTypes](nested-types.md) | `val nestedTypes: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Type`](../-type/index.md)`>` |
| [options](options.md) | `val options: `[`Options`](../-options/index.md) |
| [type](type.md) | `val type: `[`ProtoType`](../-proto-type/index.md) |

### Functions

| Name | Summary |
|---|---|
| [allowAlias](allow-alias.md) | `fun allowAlias(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [constant](constant.md) | `fun constant(name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>Returns the constant named `name`, or null if this enum has no such constant.`fun constant(tag: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): <ERROR CLASS>`<br>Returns the constant tagged `tag`, or null if this enum has no such constant. |
| [linkMembers](link-members.md) | `fun linkMembers(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`): `[`Type`](../-type/index.md)`?` |
| [retainLinked](retain-linked.md) | `fun retainLinked(linkedTypes: `[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`ProtoType`](../-proto-type/index.md)`>): `[`Type`](../-type/index.md)`?`<br>Returns a copy of this containing only the types in [linkedTypes](../-type/retain-linked.md#com.squareup.wire.schema.Type$retainLinked(kotlin.collections.Set((com.squareup.wire.schema.ProtoType)))/linkedTypes), or null if that set is empty. This will return an [EnclosingType](../-enclosing-type/index.md) if it is itself not linked, but its nested types are linked. |
| [toElement](to-element.md) | `fun toElement(): `[`EnumElement`](../../com.squareup.wire.schema.internal.parser/-enum-element/index.md) |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inherited Functions

| Name | Summary |
|---|---|
| [typesAndNestedTypes](../-type/types-and-nested-types.md) | `fun typesAndNestedTypes(): `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Type`](../-type/index.md)`>`<br>Returns all types and subtypes which are linked to the type. |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElement](from-element.md) | `fun fromElement(protoType: `[`ProtoType`](../-proto-type/index.md)`, enumElement: `[`EnumElement`](../../com.squareup.wire.schema.internal.parser/-enum-element/index.md)`): `[`EnumType`](./index.md) |

==> wire-runtime-3.7.1-javadoc.jar: wire-schema/com.squareup.wire.schema/-enum-type/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [EnumType](./index.md)

# EnumType

`data class EnumType : `[`Type`](../-type/index.md)

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `EnumType(type: `[`ProtoType`](../-proto-type/index.md)`, location: `[`Location`](../-location/index.md)`, documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstant`](../-enum-constant/index.md)`>, options: `[`Options`](../-options/index.md)`, syntax: <ERROR CLASS>)` |

### Properties

| Name | Summary |
|---|---|
| [constants](constants.md) | `val constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstant`](../-enum-constant/index.md)`>` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [nestedTypes](nested-types.md) | `val nestedTypes: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Type`](../-type/index.md)`>` |
| [options](options.md) | `val options: `[`Options`](../-options/index.md) |
| [syntax](syntax.md) | `val syntax: <ERROR CLASS>` |
| [type](type.md) | `val type: `[`ProtoType`](../-proto-type/index.md) |

### Functions

| Name | Summary |
|---|---|
| [allowAlias](allow-alias.md) | `fun allowAlias(): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [constant](constant.md) | `fun constant(name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>Returns the constant named `name`, or null if this enum has no such constant.`fun constant(tag: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): <ERROR CLASS>`<br>Returns the constant tagged `tag`, or null if this enum has no such constant. |
| [linkMembers](link-members.md) | `fun linkMembers(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`, validate: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`): `[`Type`](../-type/index.md)`?` |
| [retainLinked](retain-linked.md) | `fun retainLinked(linkedTypes: `[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`ProtoType`](../-proto-type/index.md)`>): `[`Type`](../-type/index.md)`?`<br>Returns a copy of this containing only the types in [linkedTypes](../-type/retain-linked.md#com.squareup.wire.schema.Type$retainLinked(kotlin.collections.Set((com.squareup.wire.schema.ProtoType)))/linkedTypes), or null if that set is empty. This will return an [EnclosingType](../-enclosing-type/index.md) if it is itself not linked, but its nested types are linked. |
| [toElement](to-element.md) | `fun toElement(): `[`EnumElement`](../../com.squareup.wire.schema.internal.parser/-enum-element/index.md) |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Inherited Functions

| Name | Summary |
|---|---|
| [typesAndNestedTypes](../-type/types-and-nested-types.md) | `fun typesAndNestedTypes(): `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Type`](../-type/index.md)`>`<br>Returns all types and subtypes which are linked to the type. |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElement](from-element.md) | `fun fromElement(protoType: `[`ProtoType`](../-proto-type/index.md)`, enumElement: `[`EnumElement`](../../com.squareup.wire.schema.internal.parser/-enum-element/index.md)`, syntax: <ERROR CLASS>): `[`EnumType`](./index.md) |
